@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
-our $DATE = '2016-09-26'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2016-10-25'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,7 +103,7 @@ $SPEC{gen_cli_doc_data_from_meta} = {
         'for producing CLI documentation (help/usage/POD)',
     description => <<'_',
 
-This function calls `Perinci::Sub::GetArgs::Argv`'s
+This function calls <pm:Perinci::Sub::GetArgs::Argv>'s
 `gen_getopt_long_spec_from_meta()` (or receive its result as an argument, if
 passed, to avoid calling the function twice) and post-processes it: produce
 command usage line, format the options, include information from metadata, group
@@ -132,7 +132,7 @@ _
             schema  => 'array*', # XXX envres
             description => <<'_',
 
-If you already call `Perinci::Sub::GetArgs::Argv`'s
+If you already call <pm:Perinci::Sub::GetArgs::Argv>'s
 `gen_getopt_long_spec_from_meta()`, you can pass the _full_ enveloped result
 here, to avoid calculating twice. What will be useful for the function is the
 extra result in result metadata (`func.*` keys in `$res->[3]` hash).
@@ -351,8 +351,16 @@ sub gen_cli_doc_data_from_meta {
                     $opt->{$_} = $arg_spec->{$_} if defined $arg_spec->{$_};
                 }
 
-                _add_category_from_spec($clidocdata->{option_categories},
-                                        $opt, $arg_spec, "options", 1);
+                {
+                    # we don't want argument options to end up in "Other" like
+                    # --help or -v, they are put at the end. so if an argument
+                    # option does not have category, we'll put it in the "main"
+                    # category.
+                    local $arg_spec->{tags} = ['category:main']
+                        if !$arg_spec->{tags} || !@{$arg_spec->{tags}};
+                    _add_category_from_spec($clidocdata->{option_categories},
+                                            $opt, $arg_spec, "options", 1);
+                }
                 _add_default_from_arg_spec($opt, $arg_spec);
 
             } else {
@@ -485,7 +493,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.25 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2016-09-26.
+This document describes version 0.26 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2016-10-25.
 
 =head1 SYNOPSIS
 
@@ -548,8 +556,8 @@ Sample result:
          },
        ],
        option_categories => {
-         "Cat1 options"  => { order => 50 },
-         "Other options" => { order => 99 },
+         "Cat1 options" => { order => 50 },
+         "Main options" => { order => 50 },
        },
        opts => {
          "--bool1" => {
@@ -593,8 +601,8 @@ Sample result:
              schema => ["str", { req => 1 }, {}],
              summary => "A required option as well as positional argument",
            },
-           categories => ["Other options"],
-           category => "Other options",
+           categories => ["Main options"],
+           category => "Main options",
            description => undef,
            fqarg => "str1",
            opt_parsed => { desttype => "", opts => ["str1"], type => "s" },
@@ -641,7 +649,7 @@ L<Perinci::Examples::CLI>.
 
 From Rinci function metadata, generate structure convenient for producing CLI documentation (help/usage/POD).
 
-This function calls C<Perinci::Sub::GetArgs::Argv>'s
+This function calls L<Perinci::Sub::GetArgs::Argv>'s
 C<gen_getopt_long_spec_from_meta()> (or receive its result as an argument, if
 passed, to avoid calling the function twice) and post-processes it: produce
 command usage line, format the options, include information from metadata, group
@@ -665,7 +673,7 @@ Will be passed to gen_getopt_long_spec_from_meta().
 
 Full result from gen_getopt_long_spec_from_meta().
 
-If you already call C<Perinci::Sub::GetArgs::Argv>'s
+If you already call L<Perinci::Sub::GetArgs::Argv>'s
 C<gen_getopt_long_spec_from_meta()>, you can pass the I<full> enveloped result
 here, to avoid calculating twice. What will be useful for the function is the
 extra result in result metadata (C<func.*> keys in C<< $res-E<gt>[3] >> hash).
